@@ -12,8 +12,8 @@ root = Path(__file__).parent
 if root not in sys.path:
     sys.path.insert(0, root.as_posix())
 
-from mypythontools import cicd
-from mypythontools import helpers
+import mypythontools_cicd as cicd
+import mypythontools
 
 cicd.tests.setup_tests(matplotlib_test_backend=True)
 
@@ -29,7 +29,7 @@ def setup_tests():
     cwd_backup = Path.cwd()
 
     os.chdir(test_project_path.as_posix())
-    helpers.paths.PROJECT_PATHS.reset_paths()
+    mypythontools.paths.PROJECT_PATHS.reset_paths()
 
     yield
 
