@@ -1,22 +1,18 @@
 """Push the CI pipeline. Format, create commit from all the changes, push and deploy to PyPi."""
 
-# import os
-# import inspect
-from pathlib import Path
+
+
+# TODO delete me
 import sys
+from pathlib import Path
+sys.path.insert(0, (Path.cwd().parent / 'mypythontools_cicd').as_posix())
+import mypythontools_cicd
 
-# Find paths and add to sys.path to be able to use local version and not installed mypythontools version
-root_path_str = Path(__file__).parents[1].as_posix()
-# root = Path(os.path.abspath(inspect.getframeinfo(inspect.currentframe()).filename)).parents[1]
-
-if root_path_str not in sys.path:
-    sys.path.insert(0, root_path_str)
-
-from mypythontools import cicd
+from mypythontools_cicd.project_utils import project_utils_pipeline
 
 if __name__ == "__main__":
     # All the parameters can be overwritten via CLI args
-    cicd.project_utils.project_utils_pipeline(
+    project_utils_pipeline(
         reformat=True,
         test=True,
         test_options={"virtualenvs": ["venv/37", "venv/310"]},
@@ -30,3 +26,7 @@ if __name__ == "__main__":
         deploy=True,
         allowed_branches=("master", "main"),
     )
+
+    # project_utils_pipeline(
+    #     do_only="deploy",
+    # )
